@@ -2,7 +2,7 @@ test_that("unregularized binomial models reduces to glm without intercept", {
   set.seed(3)
   n=200
   p=10
-  X <- as.matrix(rnorm_multi(n=n,vars=p,mu=0,sd=1,r=0))
+  X <- MASS::mvrnorm(n=n,mu=rep(0,p),Sigma=diag(1,p))
   y <- 1/(1+exp(-(X %*%rnorm(p,mean=0,sd=sqrt(10)) + rnorm(n,mean=0,sd=4))))
   y <- ifelse(y>0.5,1,0)
 
